#
# spec file for package manaplus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           manaplus
Version:        2.1.3.17
Release:        bp156.4.4
Summary:        A client for Evol Online and The Mana World: 2D MMORPG
License:        GPL-2.0-or-later
Group:          Amusements/Games/RPG
URL:            https://manaplus.org/
Source:         https://download.tuxfamily.org/manaplus/download/%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM fix-include-time_h.patch -- Fix missing include for time.h when not using clang
Patch0:         fix-include-time_h.patch
# PATCH-FIX-UPSTREAM add-missing-includes.patch -- Add missing include cstdint
Patch1:         add-missing-includes.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dejavu-fonts
BuildRequires:  fdupes
BuildRequires:  fontpackages-devel
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  liberation-fonts
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL_gfx)
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(SDL_net)
BuildRequires:  pkgconfig(SDL_ttf)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(physfs)
BuildRequires:  pkgconfig(sdl)
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  pkgconfig(sdl2)
%endif
Requires:       dejavu-fonts
Requires:       liberation-fonts
Recommends:     %{name}-lang
Provides:       evolonline-client = %{version}
Provides:       manaworld-client = %{version}
%lang_package

%description
ManaPlus is extended client for Evol Online, The Mana World and
similar servers based on the eAthena fork. As a 2D style game, Evol
Online creates a fantasy environment. The Mana World (TMW) is an
effort to create an MMORPG. TMW uses 2D graphics and creates a large
and diverse interactive world.

%prep
%autosetup -p1

%build
%configure --enable-unittests
make %{?_smp_mflags}

%install
%make_install
chmod -x %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%if 0%{?suse_version} <= 1500
%fdupes -s %{buildroot}%{_datadir}
%endif
%find_lang %{name}

rm -f %{buildroot}%{_datadir}/%{name}/data/fonts/dejavu*.ttf
ln -s %{_ttfontsdir}/DejaVuSans-Bold.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/dejavusans-bold.ttf
ln -s %{_ttfontsdir}/DejaVuSansMono-Bold.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/dejavusansmono-bold.ttf
ln -s %{_ttfontsdir}/DejaVuSansMono.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/dejavusansmono.ttf
ln -s %{_ttfontsdir}/DejaVuSerifCondensed-Bold.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/dejavuserifcondensed-bold.ttf
ln -s %{_ttfontsdir}/DejaVuSerifCondensed.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/dejavuserifcondensed.ttf
ln -s %{_ttfontsdir}/DejaVuSans.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/dejavusans.ttf

rm -f %{buildroot}%{_datadir}/%{name}/data/fonts/liberation*.ttf
ln -s %{_ttfontsdir}/LiberationMono-Bold.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/liberationsansmono-bold.ttf
ln -s %{_ttfontsdir}/LiberationMono-Regular.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/liberationsansmono.ttf
ln -s %{_ttfontsdir}/LiberationSans-Bold.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/liberationsans-bold.ttf
ln -s %{_ttfontsdir}/LiberationSans-Regular.ttf %{buildroot}%{_datadir}/%{name}/data/fonts/liberationsans.ttf

%if 0%{?suse_version} <= 1500
%check
make %{?_smp_mflags} check || ( cat "src/test-suite.log" && false )
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog docs/*.txt README
%{_bindir}/manaplus
%{_bindir}/dyecmd
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/manaplustest.desktop
%{_mandir}/man6/%{name}*
%{_datadir}/metainfo/%{name}.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Mon Apr 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add add-missing-includes.patch: Add missing include cstdint.
  Exposed by gcc 13.
* Tue Feb  7 2023 Carsten Ziepke <kieltux@gmail.com>
- Add BuildRequires SDL2 for openSUSE Leap: fix for building with
  sdl12_compat (Error: Failed loading SDL2 library)
* Tue Sep  6 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Add fix-include-time_h.patch to fix build on Factory
  https://gitlab.com/manaplus/manaplus/-/issues/32
* Thu Jul  7 2022 Dmitriy Perlow <dap.darkness@gmail.com>
- Update to version 2.1.3.17
  * fix: clear background under too small maps.
  * fix: porting fix for mumblemanager from NetBSD.
  * fix: alternate ip address for char and map servers.
  * fix: back to login button in world selection window.
  * fix: foreground theme color in popups.
  * add: separate auto move sync distance for legacy servers.
  * add: support for items with id bigger than 65535.
  * add: chat command /trimmemory for force trim freed memory.
  * add: switch game console support in source (by cpasjuste).
  * update: golden delicious theme.
  * change: protocol version changed to 26.
  * change: installed desktop icon type to svg (*nix).
- Tests & fdupes were disabled for TW because of failures.
* Sat May 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.9.3.23
  * fix: guild members in 2018 packet versions.
  * fix: dynamic walls on windows.
  * fix: badges state in legacy server.
  * fix: improved auto sync logic for fix desyncs.
  * add: troll emote by Tirifto.
  * add: support for packets with item id in int32.
  * add: support for 2018 packet versions.
  * add: dynamic inventory size.
  * update: different packets.
* Sun Dec 30 2018 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8.12.8
  * Fixed dyecmd crash in A and S dye.
  * Various stability fixes
  * Fixed display stats with negative values.
  * Avoid shop spam in legacy server.
  * Added new hercules packets.
- Changes from version 1.8.9.1.
  * Fixed visual issue with used tiles from empty atlases.
  * Fixed hiding deleted temporary skills.
  * Fixed crash with wrong moving paths.
  * Dont allow buy items with amount 0 from market shop types.
  * Fixed moving between slots by keyboard in character select
    dialog.
  * Added some new chat emotes.
  * Extent chat /use command for support colors and use actions.
  * Removed support for CILK plus, support for hercules plugin
    version 12 and older and text “Message” from message related
    windows.
- Spec file cleanup.
* Mon May 14 2018 wnereiz@fsf.member.org
- update to version 1.8.4.14
  * Fixed group badge update on group change.
  * Fixed possible sorting issues in party and guild tabs.
  * Fixed possible issue in building walk path.
  * Fixed possible draw issue in speech texts.
  * Added pincode support.
- Changes from version 1.8.2.17
  * Added clans support.
- Changes from version 1.7.11.11
  * Added packets for new hercules packet versions.
  * Draw basic npc equipment.
- Changes from version 1.7.10.28
  * Disable alt-tab workaround in SDL2 by default.
  * New packets.
- Changes from version 1.7.10.14
  * Fixed some wrong asserts in text command editor.
- Changes from version 1.7.9.30
  * Fixed disconnect chat command.
  * Fixed max packet version in server editor.
  * Added http tunneling in downloads.
  * Limit each download file to 500MB.
  * New packet versions from hercules.
- Changes from version 1.7.9.16
  * sorting fonts and themes lists.
  * Fixed scrolling big windows.
  * Fixed crash with simple text in chat window before connecting
    to server.
  * Fixed adding stackable items to mail window.
  * Added jewelry-simple theme with non transparent chat window.
  * Rescale skill casting animation to whole skill area.
  * Added option for max parallel sounds.
- Changes from version 1.7.9.2
  * Fixed mouse selection in some lists.
  * Added support for new mail system.
- Changes from version 1.7.8.19
  * Fixed drawing language badge.
  * hide item popup in context menu.
  * Fixed item containers scrolling if some items hidden by filter.
  * Added attributes to missile particles.
  * Added context menu way to add skill into shortcuts bar.
  * Added more than one use action for items.
- Changes from version 1.7.8.5
  * Fixed quests window redraw speed and render too long lines.
  * Fixed mouse cursor update each 10 seconds.
  * Fixed crash in help window links with old compilers.
  * Prevent server connection timeout in register dialog.
  * Improve mouse move and click emulation.
  * Added option to show player name at top or bottom.
  * Added default icons for unknown skills by types.
- Changes from version 1.7.7.22
  * Fixed character select dialog size if slots more than two rows.
  * Fixed: Show own group level if group hidden from public.
  * Fixed possible crash on exit if compiled with SDL 2.
  * Show group name in being popups.
  * Load group name, badge, commands, permissions from xml file.
- Changes from version 1.7.7.8
  * Fixed stats in item popups.
  * Added new hercules packets.
  * Allow open chat window before connection to server.
- Changes from version 1.7.6.24
  * Fixed browserbox width with small bold lines.
  * Draw color in some renderers after window resize.
  * Added server info window
  * Mark all server with free / non free / unknown label.
  * Set default theme to jewelry.
  * Improve speed in some windows.
  * Auto close death dialog if player resurrected.
  * Added new chat commands.
  * Removed auto adding sfx/ in sound files paths.
* Mon Jun 12 2017 rpm@fthiessen.de
- Update to version 1.7.6.10
- Removed upstreamed appdata.patch
* Mon Feb 20 2017 rpm@fthiessen.de
- Fixed build on Leap (autoreconf was needed)
* Sun Feb 19 2017 jengelh@inai.de
- Trim fillers from description.
* Sat Feb 18 2017 mailaender@opensuse.org
- Update to version 1.7.2.4
- Unbundle fonts
- Enable unit tests
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
- Add a lang package
- Use make install
* Tue May 29 2012 joop.boonen@opensuse.org
- Some changes specifically for openSUSE
* Tue Feb 21 2012 akaras@inbox.ru
- Update to 1.2.2.19.
- Cleanup spec file a bit.
* Sat Jul  2 2011 akaras@inbox.ru
- Add missing dependency SDL_image and compilation tools
* Fri May 27 2011 maarten.vanraes@gmail.com
- Generalise spec file to work for multiple rpm-based distros
  Sun Apr 17 00:00:00 UTC 2011 - alien <alien> 1.1.4.17-1.mga1
  + Revision: 87336
- upgrade to 1.1.4.17
  Fri Apr  8 00:00:00 UTC 2011 - alien <alien> 1.1.4.3-1.mga1
  + Revision: 82020
- Update to new version 1.1.4.3
- manaplus is now primarily for Evol Online, updating Summary and Description and add Provides
- suggests mumble
  Sat Feb 26 00:00:00 UTC 2011 - alien <alien> 1.1.2.20-1.mga1
  + Revision: 61040
- Fix BuildRequires
- Fix configure part
- Remove unneeded mv files
- Remove BuildRoot
- use tmw spec file as basis
- imported package manaplus
* Sun Jan 31 2010 incubusss@mandriva.org
  + Revision: 498772
- add version and release for Provides
* Tue Jan  5 2010 incubusss@mandriva.org
  + Revision: 486388
- add some provides on themanaworld and manaworld
- import tmw
